@@ -63,7 +63,7 @@ impl Post {
             .expect("failed to parse DateTime")
     }
 
-    pub fn rating<'a>(&'a self) -> crate::Rating {
+    pub fn rating<'a>(&'a self) -> Rating {
         use crate::Rating::*;
         match &self.rating[0..1] {
             "s" => Safe,
@@ -101,7 +101,7 @@ impl Post {
 /// The content rating of a post.
 ///
 /// See [this forum post](https://gelbooru.com/index.php?page=wiki&s=view&id=2535) for an in-depth explanation of the 3 ratings.
-#[derive(Clone, Debug)]
+#[derive(Clone, Copy, Debug, PartialEq, Eq, PartialOrd, Ord)]
 pub enum Rating {
     Safe,
     Questionable,
@@ -134,8 +134,8 @@ impl<'a> PostsRequestBuilder<'a> {
     ///
     /// ## Example
     /// ```rust
-    /// # async fn example() -> Result<(), ()> {
-    /// # use gelbooru_api::{Client, posts};
+    /// # use gelbooru_api::{Client, Error, posts};
+    /// # async fn example() -> Result<(), Error> {
     /// # let client = Client::public();
     /// posts()
     ///     .tag("hello")
@@ -159,8 +159,8 @@ impl<'a> PostsRequestBuilder<'a> {
     ///
     /// ## Example
     /// ```rust
-    /// # async fn example() -> Result<(), ()> {
-    /// # use gelbooru_api::{Client, posts};
+    /// # use gelbooru_api::{Client, Error, posts};
+    /// # async fn example() -> Result<(), Error> {
     /// # let client = Client::public();
     /// posts()
     ///     .tags(&["hello", "world"])
@@ -196,8 +196,8 @@ impl<'a> PostsRequestBuilder<'a> {
     ///
     /// ## Example
     /// ```rust
-    /// # async fn example() -> Result<(), ()> {
-    /// # use gelbooru_api::{Client, posts};
+    /// # use gelbooru_api::{Client, Error, posts};
+    /// # async fn example() -> Result<(), Error> {
     /// # let client = Client::public();
     /// posts()
     ///     .tags(&["herro", "world"])
@@ -205,7 +205,6 @@ impl<'a> PostsRequestBuilder<'a> {
     ///     .tags(&["hello", "world"])
     ///     .send(&client)
     ///     .await?;
-    ///
     /// # Ok(())
     /// # }
     /// ```
@@ -220,8 +219,8 @@ impl<'a> PostsRequestBuilder<'a> {
     ///
     /// ## Example
     /// ```rust
-    /// # async fn example() -> Result<(), ()> {
-    /// # use gelbooru_api::{Client, Rating, posts};
+    /// # use gelbooru_api::{Client, Error, Rating, posts};
+    /// # async fn example() -> Result<(), Error> {
     /// # let client = Client::public();
     /// posts()
     ///     .tags(&["hatsune_miku"])
@@ -243,8 +242,8 @@ impl<'a> PostsRequestBuilder<'a> {
     ///
     /// ## Example
     /// ```rust
-    /// # async fn example() -> Result<(), ()> {
-    /// # use gelbooru_api::{Client, Rating, posts};
+    /// # use gelbooru_api::{Client, Error, Rating, posts};
+    /// # async fn example() -> Result<(), Error> {
     /// # let client = Client::public();
     /// posts()
     ///     .tags(&["hatsune_miku"])
@@ -331,7 +330,7 @@ impl Tag {
 }
 
 /// The type of a tag.
-#[derive(Clone, Copy, Debug)]
+#[derive(Clone, Copy, Debug, PartialEq, Eq, PartialOrd, Ord)]
 pub enum TagType {
     Artist,
     Character,
@@ -342,7 +341,7 @@ pub enum TagType {
 }
 
 /// Determines what field sorts tags in a query.
-#[derive(Clone, Copy, Debug)]
+#[derive(Clone, Copy, Debug, PartialEq, Eq, PartialOrd, Ord)]
 pub enum Ordering {
     Date,
     Count,
@@ -402,8 +401,8 @@ impl TagsRequestBuilder {
     ///
     /// ## Example
     /// ```rust
-    /// # async fn example() -> Result<(), ()> {
-    /// # use gelbooru_api::{Client, Ordering, tags};
+    /// # use gelbooru_api::{Client, Error, Ordering, tags};
+    /// # async fn example() -> Result<(), Error> {
     /// # let client = Client::public();
     /// tags()
     ///     .limit(5)                 // 5 tags
@@ -423,8 +422,8 @@ impl TagsRequestBuilder {
     ///
     /// ## Example
     /// ```rust
-    /// # async fn example() -> Result<(), ()> {
-    /// # use gelbooru_api::{Client, Ordering, tags};
+    /// # use gelbooru_api::{Client, Error, Ordering, tags};
+    /// # async fn example() -> Result<(), Error> {
     /// # let client = Client::public();
     /// tags()
     ///     .limit(10)                 // 10 tags
@@ -443,8 +442,8 @@ impl TagsRequestBuilder {
     ///
     /// ## Example
     /// ```rust
-    /// # async fn example() -> Result<(), ()> {
-    /// # use gelbooru_api::{Client, Ordering, tags};
+    /// # use gelbooru_api::{Client, Error, Ordering, tags};
+    /// # async fn example() -> Result<(), Error> {
     /// # let client = Client::public();
     /// tags()
     ///     .name(&client, "solo")
@@ -464,8 +463,8 @@ impl TagsRequestBuilder {
     ///
     /// ## Example
     /// ```rust
-    /// # async fn example() -> Result<(), ()> {
-    /// # use gelbooru_api::{Client, Ordering, tags};
+    /// # use gelbooru_api::{Client, Error, Ordering, tags};
+    /// # async fn example() -> Result<(), Error> {
     /// # let client = Client::public();
     /// tags()
     ///     .names(&client, &["solo", "hatsune_miku"])
@@ -489,8 +488,8 @@ impl TagsRequestBuilder {
     ///
     /// ## Example
     /// ```rust
-    /// # async fn example() -> Result<(), ()> {
-    /// # use gelbooru_api::{Client, Ordering, tags};
+    /// # use gelbooru_api::{Client, Error, Ordering, tags};
+    /// # async fn example() -> Result<(), Error> {
     /// # let client = Client::public();
     /// tags()
     ///     .limit(10)
